/*----------------------------------------------------------------------------
*         ATMEL Microcontroller Software Support  -  ROUSSET  -
*----------------------------------------------------------------------------
* The software is delivered "AS IS" without warranty or condition of any
* kind, either express, implied or statutory. This includes without
* limitation any warranty or condition with respect to merchantability or
* fitness for any particular purpose, or against the infringements of
* intellectual property rights of others.
*----------------------------------------------------------------------------
* File Name           : Board.h
* Object              : AT91SAM7A1 Evaluation Board Features Definition File.
*
* Creation            : JPP   22/Jun/2005
*----------------------------------------------------------------------------
*/
#ifndef Board_h
#define Board_h

#include "csp.h"
#include "bsp.h"

#include "uart.h"

// IP Stack
#include "uip.h"
#include "uip_arp.h"
#include "uipopt.h"
#include "dm9000.h"

/*-------------------------------*/
/* SAM7Board Memories Definition */
/*-------------------------------*/
/* 2-Mbytes 16-bit Flash AT91BV162A */

/* Number of Chips Select */
#define NB_CS    2               /* 2 Chips Select */

/*  Chip Select Definition */
#define AMC_CSR_0  0x400030A9    /* FLASH : Base Address = 0x40000000 */
                                 /* CS Enable, Byte Select access, 0 tdf, 4MB, 3 waitstates, 16 bits */
#define AMC_CSR_1  0x48003081    /* RAM  : Base Address = 0x48000000 */
                                 /*  CS Enable, Byte Select access, 0 tdf, 4MB, 0 waitstates, 16 bits  */
#define AMC_CSR_2  0x50000000    /* Base Address = 0x50000000 CS Disable */
#define AMC_CSR_3  0x58000000    /* Base Address = 0x58000000 CS Disable */
#define AMC_CSR_4  0x60000000    /* Base Address = 0x60000000 CS Disable */
#define AMC_CSR_5  0x68000000    /* Base Address = 0x68000000 CS Disable */
#define AMC_CSR_6  0x70000000    /* Base Address = 0x70000000 CS Disable */
#define AMC_CSR_7  0x78000000    /* Base Address = 0x78000000 CS Disable */
#define MCR_VAL    0x00000017    /* Memory Control Register Value Early Read Protocol, All chip selects valid */

/*-------------------------*/
/* Push Buttons Definition */
/*-------------------------*/

#define SW2     TIOA      /* SW2 button correspond to TIOA2 pin   */
#define SW3     TIOB      /* SW3 button correspond to TIOB1 pin   */
#define SW4     IQRQ0     /* SW4 Button correspond to IRQ0 pin(44)*/

/*--------------*/
/* Master Clock */
/*--------------*/

#define EXT_OC           6000000   // Exetrnal ocilator MAINCK


#define   BIT0        0x00000001
#define   BIT1        0x00000002
#define   BIT2        0x00000004
#define   BIT3        0x00000008
#define   BIT4        0x00000010
#define   BIT5        0x00000020
#define   BIT6        0x00000040
#define   BIT7        0x00000080
#define   BIT8        0x00000100
#define   BIT9        0x00000200
#define   BIT10       0x00000400
#define   BIT11       0x00000800
#define   BIT12       0x00001000
#define   BIT13       0x00002000
#define   BIT14       0x00004000
#define   BIT15       0x00008000
#define   BIT16       0x00010000
#define   BIT17       0x00020000
#define   BIT18       0x00040000
#define   BIT19       0x00080000
#define   BIT20       0x00100000
#define   BIT21       0x00200000
#define   BIT22       0x00400000
#define   BIT23       0x00800000
#define   BIT24       0x01000000
#define   BIT25       0x02000000
#define   BIT26       0x04000000
#define   BIT27       0x08000000
#define   BIT28       0x10000000
#define   BIT29       0x20000000
#define   BIT30       0x40000000
#define   BIT31       0x80000000

#endif /* Board_h */
